==> aroundme_0_5_0.zip: aroundme_0_5_0/aroundme/template/barnraiser_01/frm_item.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>

<form action="frm_item.php" method="post" name="frm" id="id_frm">
<input type="hidden" name="group_id" value="<?php if(isset($group['group_id'])) { echo $group['group_id'];}?>" />
<input type="hidden" name="blog_id" value="<?php if(isset($subject['subject_id'])) { echo $subject['subject_id'];}?>" />


<table width="100%" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "g_menu.inc.tpl.php";
			?>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<div class="box_top">
				<?php echo $lang['hdr_subjects'];?><br />
			</div>
			
			<div class="box_mid" style="padding: 9px;">
			<table border="0" cellspacing="0" cellpadding="4" width="100%">
				<?php
				if (isset($subjects)) {
				foreach($subjects as $key => $i):
				?>
				<tr>
					<td>
						<?php
						if ($i['subject_id'] == $subject['subject_id']) {
						?>
						<?php echo $i['subject_title'];?><br />
						<?
						}
						else {
						?>
						<a href="frm_item.php?group_id=<?php echo $group['group_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>"><?php echo $i['subject_title'];?></a><br />
						<?
						}
						?>
					</td>
				</tr>
				<?php
				endforeach;
				}
				?>
			</table>
			</div>
			
			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>
		</td>

		<td width="20">&nbsp;</td>

		<td width="560" valign="top">
			<div class="box_top">
				<?php echo $subject['subject_create_datetime'];?><br />
			</div>
			
			<div class="box_mid" style="padding: 9px;">
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td valign="top">
						<span class="txt_item_title">
						<?php echo $subject['subject_title'];?><br />
						</span>
					</td>
				</tr>
				<tr>
					<td valign="top">
						<?php
						if (isset($subject['image'])) {
						?>
						<img src="get_file.php?file=<?php echo $subject['image']['file'];?>" border="0" align="left" class="picture_left" title="<?php echo $subject['image']['file_title'];?>">
						<?php  }?>
						<?php echo $subject['display_subject_body'];?><br />
					</td>
			    </tr>
				
				<tr>
					<td valign="top" colspan="2">
						<span class="txt_footer">
						<?php echo $lang['txt_from'];?>: <a href="g_member_profile.php?group_id=<?php echo $group['group_id'];?>&amp;user_id=<?php echo $author['user_id'];?>" class="txt_footer_link"><?php echo $author['profile_nic'];?></a>&nbsp;(joined: <?php echo $author['profile_create_datetime'];?>, hometown: <?php echo $author['profile_hometown'];?>)<br />
						
						<?php
						if (isset($subject['subject_sticky'])) {
							echo $lang['txt_sticky'] . ", ";
						}

						if (isset($subject['subject_locked'])) {
							echo $lang['txt_locked'] . ", ";
						}

						if (isset($subject['subject_locked'])) {
							echo $lang['txt_hidden'];
						}
						?>
						</span>
						<br />
					</td>
			    </tr>
				<tr>
					<td>
						<div class="box_edit">
							<span style="float: right">
							<?php
							if (isset($group)) {
							if ($this->group_acs->checkPermission($resource_ids['group_forum'], $privilege_ids['allow_edit']) && isset($subject['subject_id'])) {
							?>
							<a href="frm_edit.php?group_id=<?php echo $group['group_id'];?>&amp;subject_id=<?php echo $subject['subject_id'];?>" class="link_stnd"><?php echo $lang['href_edit_this'];?></a>
							<?php }}
							elseif ($subject['user_id'] == $me['user_id']) {
							?>
							<a href="frm_edit.php?subject_id=<?php echo $subject['subject_id'];?>" class="link_stnd"><?php echo $lang['href_edit_this'];?></a>
							<?php }?>
							
							<?php
							if (isset($group)) {
							?>
							&nbsp;
							<a href="frm_list.php?group_id=<?php echo $group['group_id'];?>&amp;topic_id=<?php echo $subject['topic_id'];?>" class="link_stnd"><?php echo $lang['href_topic'];?></a>
							<?php 
							}
							else {
							?>
							&nbsp;
							<a href="frm_list.php?topic_id=<?php echo $subject['topic_id'];?>" class="link_stnd"><?php echo $lang['href_topic'];?></a>
							
							<?php }?>
							
							<br />
							</span>
							<?php
							if (isset($subject['rsp'])) {
								echo "<b>" . $lang['txt_published_to']. ": </b>";
							    foreach($subject['rsp'] as $key => $i):
									
									echo trim($lang['rsp']['rsp_level'][$i['level_id']] . " " . $i['degree_id']);
									echo " (" .$lang['rsp']['status'][$i['status_id']] . ")";
									if ($key+1 < count($subject['rsp'])) {
									    echo ", ";
									}
									
								endforeach;
							}
							?><br />
						</div>
					</td>
				</tr>
			</table>
			</div>
			
			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>
			
			
			<?php
			if (isset($subject['subject_id'])) {
				//comments
				if ($subject['user_id'] == $me['user_id']) {
					$unlocked = 1;
				}
					
				if (isset($group)) {
					if ($this->group_acs->checkPermission($resource_ids['group_forum'], $privilege_ids['allow_comment']) && empty($subject['subject_locked'])) {
					    $unlocked = 1;
					}
					
					$hidden_form = array(
						"subject_id" => $subject['subject_id'], 
						"group_id" => $group['group_id']
					);
					
					$requested_comment_language_id = $group['language_id'];
				}
				else {
					if (empty($subject['subject_locked'])) {
						$unlocked = 1;
					}
					
					$hidden_form = array(
						"subject_id" => $subject['subject_id']
					);
					
					$requested_comment_language_id = $me['language_id'];
				}
				
				include $templatePath . "comment.inc.tpl.php";
			}
			?>
		</td>
	</tr>
</table>
</form>

==> aroundme_0_5_2.zip: aroundme_0_5_2/aroundme/template/barnraiser_01/frm_item.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>

<form action="frm_item.php" method="post" name="frm" id="id_frm">
<input type="hidden" name="group_id" value="<?php if(isset($group['group_id'])) { echo $group['group_id'];}?>" />
<input type="hidden" name="blog_id" value="<?php if(isset($subject['subject_id'])) { echo $subject['subject_id'];}?>" />


<table width="100%" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "g_menu.inc.tpl.php";
			?>
			
			<?php
			if (isset($subjects)) {
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<div class="box_top">
				<?php echo $lang['hdr_subjects'];?><br />
			</div>
			
			<div class="box_mid" style="padding: 9px;">
			<table border="0" cellspacing="0" cellpadding="4" width="100%">
				<?php
				foreach($subjects as $key => $i):
				?>
				<tr>
					<td>
						<?php
						if ($i['subject_id'] == $subject['subject_id']) {
						?>
						<?php echo $i['subject_title'];?><br />
						<?
						}
						else {
						?>
						<a href="frm_item.php?group_id=<?php echo $group['group_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>"><?php echo $i['subject_title'];?></a><br />
						<?
						}
						?>
					</td>
				</tr>
				<?php
				endforeach;
				?>
			</table>
			</div>
			
			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>
			<?php }?>
			
			<?php
			if (isset($subject)) {
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" /><br />
			
			<?php
			if (isset($subject)) {
			if (isset($group)) {
				$hidden_form = array(
					"item_id" => $subject['subject_id'], 
					"group_id" => $group['group_id'],
					"subject_id" => $subject['subject_id']
				);
			}
			else {
				$hidden_form = array(
					"item_id" => $subject['subject_id'],
					"subject_id" => $subject['subject_id']
				);
			}
			
			if (isset($_REQUEST['user_id'])) {
				$hidden_form['user_id'] = $_REQUEST['user_id'];
			}
			
			$show_network = 1;
			
			include $templatePath . "tag.inc.tpl.php";
			}
			?>
			<?php }?>
		</td>

		<td width="20">
			<img src="<?php echo $templatePath;?>img/pixel.png" width="20" height="1" alt="" /><br />
		</td>

		<td width="560" valign="top">
			<div class="box_top">
				<?php echo $subject['subject_create_datetime'];?><br />
			</div>
			
			<div class="box_mid" style="padding: 9px;">
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td valign="top">
						<span class="txt_item_title">
						<?php echo $subject['subject_title'];?><br />
						</span>
					</td>
				</tr>
				<tr>
					<td valign="top">
						<?php
						if (isset($subject['image'])) {
						?>
						<img src="get_file.php?file=<?php echo $subject['image']['file'];?>" border="0" align="left" class="picture_left" title="<?php echo $subject['image']['file_title'];?>">
						<?php  }?>
						<?php echo $subject['display_subject_body'];?><br />
					</td>
			    </tr>
				
				<tr>
					<td valign="top" colspan="2">
						<span class="txt_footer">
						<?php echo $lang['txt_from'];?>: <a href="g_member_profile.php?group_id=<?php echo $group['group_id'];?>&amp;user_id=<?php echo $author['user_id'];?>" class="txt_footer_link"><?php echo $author['profile_nic'];?></a>&nbsp;(joined: <?php echo $author['profile_create_datetime'];?>, hometown: <?php echo $author['profile_hometown'];?>)<br />
						
						<?php
						if (isset($subject['subject_sticky'])) {
							echo $lang['txt_sticky'] . ", ";
						}

						if (isset($subject['subject_locked'])) {
							echo $lang['txt_locked'] . ", ";
						}

						if (isset($subject['subject_locked'])) {
							echo $lang['txt_hidden'];
						}
						?>
						</span>
						<br />
					</td>
			    </tr>
				<tr>
					<td>
						<div class="box_edit">
							<span style="float: right">
							<?php
							if (isset($group)) {
							if ($this->group_acs->checkPermission($resource_ids['group_forum'], $privilege_ids['allow_edit']) && isset($subject['subject_id'])) {
							?>
							<a href="frm_edit.php?group_id=<?php echo $group['group_id'];?>&amp;subject_id=<?php echo $subject['subject_id'];?>" class="link_stnd"><?php echo $lang['href_edit_this'];?></a>
							<?php }}
							elseif ($subject['user_id'] == $me['user_id']) {
							?>
							<a href="frm_edit.php?subject_id=<?php echo $subject['subject_id'];?>" class="link_stnd"><?php echo $lang['href_edit_this'];?></a>
							<?php }?>
							
							<?php
							if (isset($group)) {
							?>
							&nbsp;
							<a href="frm_list.php?group_id=<?php echo $group['group_id'];?>&amp;topic_id=<?php echo $subject['topic_id'];?>" class="link_stnd"><?php echo $lang['href_topic'];?></a>
							<?php 
							}
							else {
							?>
							&nbsp;
							<a href="frm_list.php?topic_id=<?php echo $subject['topic_id'];?>" class="link_stnd"><?php echo $lang['href_topic'];?></a>
							
							<?php }?>
							
							<br />
							</span>
							<?php
							if (isset($subject['rsp'])) {
								echo "<b>" . $lang['txt_published_to']. ": </b>";
							    foreach($subject['rsp'] as $key => $i):
									
									echo trim($lang['rsp']['rsp_level'][$i['level_id']] . " " . $i['degree_id']);
									echo " (" .$lang['rsp']['status'][$i['status_id']] . ")";
									if ($key+1 < count($subject['rsp'])) {
									    echo ", ";
									}
									
								endforeach;
							}
							?><br />
						</div>
					</td>
				</tr>
			</table>
			</div>
			
			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>
			
			
			<?php
			if (isset($subject['subject_id'])) {
				//comments
				if ($subject['user_id'] == $me['user_id']) {
					$unlocked = 1;
				}
					
				if (isset($group)) {
					if ($this->group_acs->checkPermission($resource_ids['group_forum'], $privilege_ids['allow_comment']) && empty($subject['subject_locked'])) {
					    $unlocked = 1;
					}
					
					$hidden_form = array(
						"subject_id" => $subject['subject_id'], 
						"group_id" => $group['group_id']
					);
					
					$requested_comment_language_id = $group['language_id'];
				}
				else {
					if (empty($subject['subject_locked'])) {
						$unlocked = 1;
					}
					
					$hidden_form = array(
						"subject_id" => $subject['subject_id']
					);
					
					$requested_comment_language_id = $me['language_id'];
				}
				
				if (isset($_REQUEST['user_id'])) {
					$hidden_form['user_id'] = $_REQUEST['user_id'];
				}
				
				include $templatePath . "comment.inc.tpl.php";
			}
			?>
		</td>
	</tr>
</table>
</form>
